from qlatent.qmnli.qmnli import _QMNLI, SCALE

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

class GAD7Q1(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I feel {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['nervous', 'anxious', 'on edge'],
            emo_neg=['calm', 'peaceful', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":1,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling nervous, anxious or on edge'
            },
            **kwargs
        )

class GAD7Q2(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I was {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['nervous', 'bothered', 'disturbed'],
            emo_neg=['peaceful','calm', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
              "Factor":"GAD",
              "Ordinal":2,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Not being able to stop or control worrying'
            },
            **kwargs
        )

class GAD7Q3(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I felt {emotion} about different things.",
            template="It is {intensifier} correct.",
            emo_pos=['worryied', 'stressed', 'nervous'],
            emo_neg=['confident', 'tranquil'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":3,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Worrying too much about different things'
            },
            **kwargs
        )

class GAD7Q4(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I've been having {emotion} relaxing.",
            template="It is {intensifier} correct.",
            emo_pos=['trouble', 'difficulty', ],
            emo_neg=['no problem', 'an easy time'],

            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":4,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble relaxing'
            },
            **kwargs
        )

class GAD7Q5(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I felt {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['restless', 'agitated', 'nervous'],
            emo_neg=['calm', 'tranquil', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":5,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Being so restless that it is hard to sit still'
            },
            **kwargs
        )

class GAD7Q6(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I became {emotion}.",
            template="It is {intensifier} correct.",
            emo_pos=['annoyed', 'irritated', 'frustrated', 'bothered'],
            emo_neg=['calm', 'tranquil', 'peaceful', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":6,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Becoming easily annoyed or irritable'
            },
            **kwargs
        )

class GAD7Q7(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="Over the last 2 weeks, I felt {emotion} about upcoming events.",
            template="It is {intensifier} correct.",
            emo_pos=['afraid', 'scared'],
            emo_neg=['calm', 'tranquil', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD",
                      "Ordinal":7,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling afraid as if something awful might happen'
            },
            **kwargs
        )

gad2_qmnli = [GAD7Q1, GAD7Q2]
gad7_qmnli = [GAD7Q1, GAD7Q2, GAD7Q3, GAD7Q4, GAD7Q5, GAD7Q6, GAD7Q7]
gad_qmnli = gad7_qmnli


from qlatent.qmnli.qmnli import QMNLI, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

kw_attitude_neg = ["meaningless", "dull", "aimless", 'boring']
kw_attitude_pos = ["meaningful", "interesting", "fulfilling", 'fascinating']
dict_attitude = dict_pos_neg(kw_attitude_pos,kw_attitude_neg, 1.0)


class SOCQ4(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="What goes around me is {index} to me.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Meaningfulness",
                      "Ordinal":4,
                      "Original":"Do you have the feeling that you don’t really care what goes on around you? "
        },
        **kwargs,
    )

kw_attitude_neg = ['surprised by','puzzled by']
kw_attitude_pos = ['expecting','anticipating']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)


class SOCQ5(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I am {frequency} {index} the behavior of people I thought I knew well.",
        answer_template="True.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Comprehensibility",
                      "Ordinal":5,
                      "Original":"Has it happened in the past that you were surprised by the behavior of people whom you thought you knew well? "
        },
        **kwargs,
    )

kw_attitude_neg = ["disappointed", 'failed']
kw_attitude_pos = ["supported", "helped"]
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ6(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="People whom I counted on {frequency} {index} me.",
        answer_template="True.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Manageability",
                      "Ordinal":6,
                      "Original":"Has it happened that people whom you counted on disappointed you? "
        },
        **kwargs,
    )

kw_attitude_neg = ["meaningless", "dull", "aimless", 'boring']
kw_attitude_pos = ["meaningful", "interesting", "fulfilling", 'fascinating']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ8(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="My life are {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Meaningfulness",
                      "Ordinal":8,
                      "Original":"Until now your life has had: "
        },
        **kwargs,
    )

kw_attitude_neg = ["unfairly", "unjustly", "with discrimination", "unequally"]
kw_attitude_pos = ["fairly", "justly", "equally"]
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ9(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I feel that I am being treated {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Manageability",
                      "Ordinal":9,
                      "Original":"Do you have the feeling that you’re being treated unfairly? "
        },
        **kwargs,
    )

kw_attitude_neg = ["helpless", "hopeless", 'powerless']
kw_attitude_pos = ["easy", "comfortable", "relaxed"]
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ12(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__( 
        context_template="In unfamiliar situation I feel {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Comprehensibility",
                      "Ordinal":12,
                      "Original":"Do you have the feeling that you’re in an unfamiliar situation and don’t know what to do?"
        },
        **kwargs,
    )

kw_attitude_neg = ["meaningless", "dull", "aimless", 'boring']
kw_attitude_pos = ["meaningful", "interesting", "fulfilling", 'fascinating']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ16(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="Things I do every day are {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Meaningfulness",
                      "Ordinal":16,
                      "Original":"Doing the things you do every day is: "
        },
        **kwargs,
    )

kw_attitude_pos = ["clear", "coherent", 'logical', 'comprehensible']
kw_attitude_neg = ["mixed-up", "confounded"]
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ19(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I have {index} feelings and ideas.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Comprehensibility",
                      "Ordinal":19,
                      "Original":"Do you have very mixed-up feelings and ideas? "
        },
        **kwargs,
    )

kw_attitude_neg = ["unwanted", 'undesired']
kw_attitude_pos = ['joyful', 'good']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ21(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I have {index} feelings.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Comprehensibility",
                      "Ordinal":21,
                      "Original":"Does it happen that you have feelings inside you would rather not feel? "
        },
        **kwargs,
    )

kw_attitude_neg = ["loser", "sad sack"]
kw_attitude_pos = ["winner", "success"]
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ25(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I’m a {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Manageability",
                      "Ordinal":25,
                      "Original":"Many people—even those with a strong character—sometimes feel like sad sacks (losers) in certain situations. How often have you felt this way in the past? "
        },
        **kwargs,
    )

kw_attitude_pos = ["estimate in proportion", "judge in proportion"]
kw_attitude_neg = ["overestimate","misjudge",'underestimate']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ26(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I {index} the importence of something that happened.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Comprehensibility",
                      "Ordinal":26,
                      "Original":"When something happened‚ you have generally found that: you overestimated or underestimated its importance, you saw things in the right proportion"
        },
        **kwargs,
    )

kw_attitude_neg = ["meaningless", "dull", "aimless", 'boring']
kw_attitude_pos = ["meaningful", "interesting", "fulfilling", 'fascinating']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ28(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="The things I do in my daily life are {index} to me.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Meaningfulness",
                      "Ordinal":28,
                      "Original":"How often do you have the feeling that there’s little meaning in the things you do in your daily life? "
        },
        **kwargs,
    )

kw_attitude_neg = ["out of control", "uncontrollable", 'unmanageable']
kw_attitude_pos = ["contained", "collected", 'controlled']
dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

class SOCQ29(QMNLI):
  
  q_index=["index"]
  q_scale="frequency"

  def __init__(self, **kwargs):
    super().__init__(
        context_template="I feel that my feelings are {index}.",
        answer_template="It is {frequency} correct.",
        dimensions={
            "frequency":frequency_weights,
            "index":dict_attitude,
        },
        descriptor = {"Questionnair":"SOC",
                      "Factor":"Manageability",
                      "Ordinal":29,
                      "Original":"How often do you have feelings that you’re not sure you can keep under control? "
        },
        **kwargs,
    )

soc_qmnli = [SOCQ4, SOCQ5, SOCQ6, SOCQ8, SOCQ12, SOCQ16, SOCQ19, SOCQ21, SOCQ25, SOCQ26, SOCQ28, SOCQ29]


from pathlib import Path
import importlib

def load_questions(pattern='_qmnli.py'):
    base_path = Path(__file__).parent.parent
    questions = []
    for questionnaire_path in list(base_path.glob(f'**/*{pattern}')):
        questionnaire_path = questionnaire_path.relative_to(base_path)
        name = questionnaire_path.name.replace(".py", "")
        file = questionnaire_path
        module_path = str(questionnaire_path.parent).replace('/', '.') + f'.{name}'
        module = importlib.import_module(module_path)
        if hasattr(module, name):
            print('load:', name)
            questions += getattr(module, name)
            
    return questions


from qlatent.qmnli.qmnli import _QMNLI, SCALE

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

class BIG5Q1(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I {intensifier} {emotion} new experiences and trying new things.",
            template="It is correct.",
            emo_pos=['am open to', 'enjoy', 'like'],
            emo_neg=['avoid', 'reject', 'dislike'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":1,
              "Original":'I am open to new experiences and enjoy trying new things.'
            },
            **kwargs
        )

class BIG5Q2(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion}.",
            template="It is correct.",
            emo_pos=['inventive', 'imaginative', 'creative'],
            emo_neg=['lacking imagination', 'boring'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":2,
              "Original":'I am imaginative and have a rich inner life.'
            },
            **kwargs
        )

class BIG5Q3(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I {intensifier} {emotion} new experiences.",
            template="It is correct.", 
            emo_pos=['seek out', 'look for', 'want to have'],
            emo_neg=['decline', 'dislike', 'give up on'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":3,
              "Original":'I am adventurous and seek out new experiences.'
            },
            **kwargs
        )

class BIG5Q4(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I {intensifier} {emotion} the details.",
            template="It is correct.",
            emo_pos=['closely inspect', 'pay attention to', 'am thorough in'],
            emo_neg=['overlook', 'miss out on', 'tend to neglect'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":4,
            "Original":'I am thorough and pay attention to detail.'
            },
            **kwargs
        )

class BIG5Q5(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion}.",
            template="It is correct.",
            emo_pos=['responsible', 'dependable', 'trustworthy'],
            emo_neg=['unreliable', 'reckless', 'unaccountable'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":5,
            "Original":'I am responsible and dependable.'
            },
            **kwargs
        )

class BIG5Q6(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I {intensifier} like to be {emotion}.",
            template="It is correct.",
            emo_pos=['organized', 'arranged'],
            emo_neg=['messy', 'disordered'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":6,
            "Original":'I am organized and like to keep things tidy.'
            },
            **kwargs
        )

class BIG5Q7(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion} around other people.",
            template="It is correct.",
            emo_pos=['talkative', 'chatty', 'amiable'],
            emo_neg=['quiet', 'silent', 'withdrawn', 'shy'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":7,
            "Original":'I am talkative and enjoy being around others.'
            },
            **kwargs
        )

class BIG5Q8(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion}.",
            template="It is correct.",
            emo_pos=['sociable', 'in the center of attention'],
            emo_neg=['quiet', 'reserved', 'shy'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":8,
            "Original":'I am outgoing and enjoy being the center of attention.'
            },
            **kwargs
        )

class BIG5Q9(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion}.",
            template="It is correct.",
            emo_pos=['sociable', 'friendly', 'approachable'],
            emo_neg=['distant','unfriendly', 'unsociable'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":9,
            "Original":'I am sociable and make friends easily.'
            },
            **kwargs
        )

class BIG5Q10(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion} other people's feelings.",
            template="It is correct.",
            emo_pos=['considerate towards', 'respectful towards', 'care about'],
            emo_neg=['indifferent towards', 'emotionally distant towards', 'insensitive towards'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":10,
            "Original":"I am considerate and care about other people's feelings."
            },
            **kwargs
        )

class BIG5Q11(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} {emotion} towards others.",
            template="It is correct.",
            emo_pos=['compassionate', 'empathetic', 'sympathetic'],
            emo_neg=['indifferent', 'careless', 'apathetic'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":11,
            "Original":"I am compassionate and empathetic towards others."
            },
            **kwargs
        )

class BIG5Q12(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I {intensifier} {emotion} with others.",
            template="It is correct.",
            emo_pos=['cooperate', 'work well', 'helpful'],
            emo_neg=['disobliging', 'unsupportive'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":12,
            "Original":"I am cooperative and work well with others."
            },
            **kwargs
        )

class BIG5Q13(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} easily {emotion} about things.",
            template="It is correct.",
            emo_pos=['stressed', 'worry', 'concern'],
            emo_neg=['calmed', 'collected', 'composed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":13,
            "Original":"I am easily stressed and worry about things."
            },
            **kwargs
        )

class BIG5Q14(_QMNLI):
    def __init__(self, **kwargs):
        super().__init__(
            context="I am {intensifier} easily {emotion}.",
            template="It is correct.",
            emo_pos=['upset', 'prone to mood swings', 'agitated'],
            emo_neg=['calmed', 'relaxed'],
            intensifiers=frequency_weights,
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":14,
            "Original":"I am easily upset and prone to mood swings."
            },
            **kwargs
        )

big5_qmnli = [BIG5Q1, BIG5Q2, BIG5Q3, BIG5Q4, BIG5Q5, BIG5Q6, BIG5Q7, BIG5Q8, BIG5Q9, BIG5Q10, BIG5Q11, BIG5Q12, BIG5Q13, BIG5Q14]


from setuptools import setup, find_packages

setup(
name="qpsychometric",
version="1.0.3",
description="A Python package containing implemented psychometrics for LLMs.",
packages=find_packages(),
project_urls={
        "Academic Article": "https://openreview.net/pdf/026597881acf1899856edfa5147390a6a60bd3a8.pdf",
    },
classifiers=[
"Programming Language :: Python :: 3",
"License :: OSI Approved :: Apache Software License",
"Operating System :: OS Independent",
],
include_package_data=True,
python_requires=">=3.8",
)